@@ -1,4 +1,5 @@
 """s3path utilities."""
+import logging
 import shutil
 from pathlib import Path
 from typing import Union
@@ -7,12 +8,16 @@ from s3path import S3Path
 
 AnyPath = Union[Path, S3Path]
 
+log = logging.getLogger(__name__)
+
 
 def rmdirtree(path: AnyPath) -> None:
     """Remove the local or S3 path."""
+    log.info(f"Removing path {path}.")
     if isinstance(path, S3Path):
         if path.exists():
             path.rmdir()
     else:
         shutil.rmtree(path, ignore_errors=True)
     assert list(path.rglob("*")) == []
+    log.info(f"Removed path {path}.")
